@@ -47,7 +47,7 @@ use Carp;
 use Data::Dumper;
 use File::Slurp;
 
-our $VERSION = 0.48;
+our $VERSION = 0.49;
 
 sub swit_startup {}
 
@@ -175,13 +175,6 @@ sub swit_schedule {
 	});
 }
 
-sub swit_hostport {
-	my ($class, $r) = @_;
-	my $res = $r->get_server_name;
-	$res .= ":" . $r->get_server_port if $r->get_server_port != 80;
-	return $res;
-}
-
 sub swit_failure {
 	my ($class, @res) = @_;
 	return [ 'INTERNAL', shift @res, \@res ];
